WeatherAlerts Docs
**********************

.. Warning::
   Future versions of WeatherAlerts will not be compatibile with this version.
   This module is in alpha, it's API can and will change. New versions will likely break backwards compatibility.
   This will become more stable as we approch the 1.0 release. For now, I encourage you to test new versions with your
   program before upgrading.

.. Note::
   You are looking at the documentation for version 0.4.9.
   Current work is being done on 0.5.0, a completly rewritten version which will be released soon.
   If you'd like to check the documentation for the new version, check `here <http://weatheralerts.readthedocs.org/en/rewrite/>`_


Welcome
=============
WeatherAlerts is a python project I started in Nov 2011 as part of another weather/python project I was working on.
I wanted to create a python module to interact with the Emergency Alerts data provided free from the
National Weather Service, rather than have to sign up and potentially pay a 3rd party to give me access to this data.
Please take a look through the documentation here, if you still have questions, contact me.


Documentation Contents
=======================

.. toctree::
   :maxdepth: 2

   about
   use
   devstatus
   contact
   changelog
   module

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

